package me.springframework.sample.javame.factory;

/**
 * An object factory, providing access to a network of wired objects, 
 * some of them lazily instantiated. You can refer to some objects by 
 * name. The named objects managed by this class are:
 *
 * <ul>
 * <li>movieFinder : {@link me.springframework.sample.javame.InMemoryMovieStore}</li> 
 * </ul>
 * 
 */
public class BeanFactory  {

    /**
     * A cached reference to the bean named "movieFinder".
     */
    private me.springframework.sample.javame.InMemoryMovieStore movieFinder;
  
    /**
     * Constructs an instance of this bean factory.
     */
    public BeanFactory() {
        start();
    }
  
    /**
     * Returns an object by looking it up by its name.
     *
     * @return The object with the given name, constructed by the BeanFactory.
     * @see BeanFactory
     * @throws java.lang.RuntimeException In case of problems creating the bean.
     */
    public synchronized Object getBean(String name) throws java.lang.RuntimeException {
        if ("movieFinder".equals(name)) return getMovieFinder();
        return null; // Keep the compiler happy
    }

    /**
     * Creates bean movieFinder.
     */
    private final me.springframework.sample.javame.InMemoryMovieStore getMovieFinder() {
        if (movieFinder == null) {
            try {
                movieFinder = new me.springframework.sample.javame.InMemoryMovieStore();
                movieFinder.setMovies(createSource179());
                // No init method 
            } catch(Exception e) {
                throw new java.lang.RuntimeException(e.getMessage());
            }
        }    
        return movieFinder;
    }


    /**
     * Creates a bean of type me.springframework.sample.api.BaseMovie, injected into the 1th element of the list of the movies property of bean movieFinder. 
     * 
     * @return One of the required instances of {@link me.springframework.sample.api.BaseMovie}.
     */
    private final me.springframework.sample.api.BaseMovie createSource178() {
        try {
            me.springframework.sample.api.BaseMovie result = new me.springframework.sample.api.BaseMovie();
            result.setTitle("Into the Wild");
            result.setYear(2008);
            result.setDirector("Sean Penn");
            return result;
        } catch(Exception e) {
            throw new java.lang.RuntimeException(e.getMessage());
        }
    }

    /**
     * Creates a bean of type me.springframework.sample.api.BaseMovie, injected into the 0th element of the list of the movies property of bean movieFinder. 
     * 
     * @return One of the required instances of {@link me.springframework.sample.api.BaseMovie}.
     */
    private final me.springframework.sample.api.BaseMovie createSource173() {
        try {
            me.springframework.sample.api.BaseMovie result = new me.springframework.sample.api.BaseMovie();
            result.setDirector("Katrin Ottarsdottir");
            result.setTitle("Bye Bye Blue Bird");
            result.setYear(1999);
            return result;
        } catch(Exception e) {
            throw new java.lang.RuntimeException(e.getMessage());
        }
    }

    /**
     * Creates the list of the movies property of bean movieFinder.
     * 
     * @return A list of objects.
     */
    private final java.util.Vector createSource179() {
        java.util.Vector result = new java.util.Vector();
        result.addElement(createSource173());
        result.addElement(createSource178());
        return result;
    }

    /**
     * "Starts" the BeanFactory; instances that have been 
     * configured to be loaded eagerly will be loaded, and their init-methods
     * will be called. 
     */
    private final void start() {
        // Skipping movieFinder
    }
    
    /**
     * "Stops" the BeanFactory; instances that have an 
     * destroy-method defined will get that method invoked.
     */
    public final void stop() {
        // Skipping movieFinder
    }
    
    	    
}